Blue class
Constructors
- Blue()
Properties
-
all
→ List<
NizeColor> -
no setter
- cloudWisp ↔ NizeColor
-
getter/setter pair
- coldSteel ↔ NizeColor
-
getter/setter pair
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- midnight ↔ NizeColor
-
getter/setter pair
- midnightSapphire ↔ NizeColor
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trueBlue ↔ NizeColor
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited