Brown class
Constructors
- Brown()
Properties
-
all
→ List<
NizeColor> -
no setter
- chocolateNoir ↔ NizeColor
-
getter/setter pair
- earthlyMocha ↔ NizeColor
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- poop ↔ NizeColor
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trueBrown ↔ NizeColor
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited